@@ -1,8 +1,9 @@
 # Bughouse Chess
 
-from pychess.Utils.const import *
+from pychess.Utils.const import VARIANTS_OTHER_NONSTANDARD, BUGHOUSECHESS
 from pychess.Utils.Board import Board
 
+
 class BughouseBoard(Board):
     variant = BUGHOUSECHESS
     __desc__ = _("FICS bughouse: http://www.freechess.org/Help/HelpFiles/bughouse.html")
