@@ -7,7 +7,8 @@ from pychess.Utils.Board import Board
 class CrazyhouseBoard(Board):
     variant = CRAZYHOUSECHESS
     __desc__ = _(
-        "FICS crazyhouse: http://www.freechess.org/Help/HelpFiles/crazyhouse.html")
+        "FICS crazyhouse: http://www.freechess.org/Help/HelpFiles/crazyhouse.html"
+    )
     name = _("Crazyhouse")
     cecp_name = "crazyhouse"
     need_initial_board = False
