@@ -8,7 +8,9 @@ THEBANSTART = "1p6/2p3kn/3p2pp/4pppp/5ppp/8/PPPPPPPP/PPPPPPKN w - - 0 1"
 
 class ThebanBoard(Board):
     variant = THEBANCHESS
-    __desc__ = _("Variant developed by Kai Laskos: http://talkchess.com/forum/viewtopic.php?t=40990")
+    __desc__ = _(
+        "Variant developed by Kai Laskos: http://talkchess.com/forum/viewtopic.php?t=40990"
+    )
     name = _("Theban")
     cecp_name = "normal"
     need_initial_board = True
